@@ -12,6 +12,7 @@ plum.its <- function(ssize=2e3, set=get('info'), ACCEP_EV=20, EVERY_MULT=5, BURN
 }
 
 
+
 #' @name Plum_runs
 #' @title List the folders present in the current core directory.
 #' @description Lists all folders located within the core's directory.
@@ -275,7 +276,9 @@ read.dets.plum <- function(core, coredir, n.supp=c(), date.sample, sep=",", dec=
     }
     n.supp <- choice(nsupp.infile, nsupp.asoption, "number of supported data", "",, check.equi(dets))
 	
-	
+  if(n.supp == 0 && ra.case==0)
+	stop("If ra.case=0 (no radium measurements), then n.supp should be 1 or more")
+
   if(length(Bqkg) == 0 || !(Bqkg %in% c(0, 1))) {
     message("Assuming that the Pb units are in Bq/kg, Bqkg=1")
     Bqkg <- 1
@@ -400,12 +403,25 @@ Plum.cleanup <- function(set=get('info')) {
   files <- c(paste0(set$prefix, ".bacon"), paste0(set$prefix, ".out"),
     paste0(set$prefix, ".pdf"), paste0(set$prefix, "_ages.txt"),
     paste0(set$coredir,set$core, "/", set$core, "_settings.txt"))
-  for(i in files)
-    if(file.exists(i))
-      tmp <- file.remove(i)
-  if(exists("tmp"))
-    rm(tmp)
-  message("Previous Plum runs of core ", set$core, " with thick=", set$thick, " deleted. Now try running the core again\n")
+	
+    safe_remove <- function(file) 
+      tryCatch( if(file.exists(file)) file.remove(file),
+        warning = function(w) 
+          message("Warning while trying to remove ", file, ": ", conditionMessage(w)), 
+        error = function(e) 
+          message("Error while trying to remove ", file, ": ", conditionMessage(e))
+      )
+	
+	for(i in files) 
+	  if(file.exists(i)) {
+    #    result <- try(file.remove(i), silent = TRUE)
+        result <- safe_remove(i)
+        if(inherits(result, "try-error")) 
+          message("Could not remove file: ", i) else 
+        if(!result) 
+          message("File does not exist or could not be deleted: ", file)
+	  }
+  message("Previous Plum runs of core ", set$core, " with thick=", set$thick, " deleted. Now try running the core again")
 }
 
 
@@ -651,8 +667,8 @@ write.plum.file <- function(set=get('info'), younger.than=c(), older.than=c(), s
     if(length(set$acc.mean)==1)
       set$acc.mean <- rep(set$acc.mean, length(hiatus.depths)+1)
     if(length(set$hiatus.max)==1)
-      set$hiatus.max <- rep(set$hiatus.max, length(hiatus.depths))
-    if(save.info)
+      set$hiatus.max <- rep(set$hiatus.max, length(hiatus.depths))    
+	if(save.info)
       assign_to_global("info", set)
     cat("\n\n### Depths and priors for fixed hiatuses, in descending order",
       "\n##### cm  alpha beta      ha     hb", file=fl)
